TranscriptWriter

Struct TranscriptWriter 

pub struct TranscriptWriter<F, T> {
    sponge: T,
    transcript: Transcript<F>,
}
The prover-side interface for interacting with a transcript sponge. A TranscriptWriter acts as a wrapper around a TranscriptSponge and additionally keeps track of all the append/squeeze operations to be able to generate a serializable Transcript.

Fields

sponge: T

The sponge that this writer is using to append/squeeze elements.

transcript: Transcript<F>

A mutable transcript which keeps a record of all the append/squeeze operations.

Implementations

Source

impl<F: Field, Tr: TranscriptSponge<F>> TranscriptWriter<F, Tr>

pub fn get_transcript(self) -> Transcript<F>

Destructively extract the transcript produced by this writer. This should be the last operation performed on a TranscriptWriter.

pub fn new(label: &str) -> Self

Creates an empty sponge. label is an identifier and will be absorbed into the transcript upon intialization.