pub struct TranscriptReader<F, T> {
sponge: T,
transcript: Transcript<F>,
next_element: (usize, usize),
}Expand description
A TranscriptReader is typically created using a Transcript produced by a
TranscriptWriter.
Its operation is similar to that of the writer, except that instead of an
“append” operation, it provides a “consume” operation which returns the next
field element that was appended to the circuit by the prover. The user of a
TranscriptReader (typically that is the verifier) is responsible for
running any checks (if necessary) to verify the validity of the consumed
elements. The “squeeze” operation behaves similarly to that of a
TranscriptWriter.
Consume/Squeeze operations on a TranscriptReader may return errors when an
unexpected operation is requested. An operation can be unexpected if it
doesn’t match the sequence of operations performed by the TranscriptWriter
that produced the Transcript used in the initialization of the reader.
Fields
sponge: TThe sponge that this reader is wrapping around.
transcript: Transcript<F>The transcript that this reader is using to consume elements from and verify the order of operations is valid.
next_element: (usize, usize)An internal state representing the position of the next operation on the transcript.
Implementations
Sourceimpl<F: Field, T: TranscriptSponge<F>> TranscriptReader<F, T>
impl<F: Field, T: TranscriptSponge<F>> TranscriptReader<F, T>
Sourcefn consume_input_element(&mut self, label: &'static str) -> Result<F>
fn consume_input_element(&mut self, label: &'static str) -> Result<F>
Reads off a single input element from the transcript and returns it if it exists. Note that this is identical to TranscriptReader::consume_element(), but using Operation::AppendInput rather than Operation::Append. Note that this function should not be called externally!
The operation can fail with:
TranscriptReaderError::ConsumeInputError: if there are no more elements to consume or if a squeeze or non-input consume was expected.
label is as described in the other TranscriptReader functions.
Sourcefn consume_input_hash_chain_digest_element(
&mut self,
label: &'static str,
) -> Result<F>
fn consume_input_hash_chain_digest_element( &mut self, label: &'static str, ) -> Result<F>
Reads off a single element from the hash chain digest elements in an input commitment and returns it if it exists. Note that this function should not be called externally!
Sourceimpl<F: Debug, Tr: TranscriptSponge<F>> TranscriptReader<F, Tr>
impl<F: Debug, Tr: TranscriptSponge<F>> TranscriptReader<F, Tr>
Sourcepub fn new(transcript: Transcript<F>) -> Self
pub fn new(transcript: Transcript<F>) -> Self
Generate a new TranscriptReader to operate on a given transcript.
Sourcefn advance_indices(&mut self) -> Result<()>
fn advance_indices(&mut self) -> Result<()>
Internal method used to advance the internal state to the next operation.