pub struct TranscriptWriter<F, T> {
sponge: T,
transcript: Transcript<F>,
}Expand description
The prover-side interface for interacting with a transcript sponge. A
TranscriptWriter acts as a wrapper around a TranscriptSponge and
additionally keeps track of all the append/squeeze operations to be able to
generate a serializable Transcript.
Fields
sponge: TThe sponge that this writer is using to append/squeeze elements.
transcript: Transcript<F>A mutable transcript which keeps a record of all the append/squeeze operations.
Implementations
Sourceimpl<F: Field, Tr: TranscriptSponge<F>> TranscriptWriter<F, Tr>
impl<F: Field, Tr: TranscriptSponge<F>> TranscriptWriter<F, Tr>
Sourcepub fn get_transcript(self) -> Transcript<F>
pub fn get_transcript(self) -> Transcript<F>
Destructively extract the transcript produced by this writer.
This should be the last operation performed on a TranscriptWriter.